# mh/__ini__.py
'''
This documentation comes from within the code.

Deffinition of the API
'''

__version__ = '0.0.31'

import mh.mh as mh

EG_VAR2 = mh.EG_VAR
testFunction = mh.testFunction
Mh = mh.Mh




'''An example of an internal module within the package

Although the intenals are not explicity exposed, they are still available via

    import mhlib
    mhlib.eg.MhEg().runMhEg()

    import mhlib.l2.l2
    mhlib.l2.l2.L2EG_VAR
'''




# perf_test

import os
import sys

#testdir = os.path.dirname(__file__)
#testdir = os.path.realpath(__file__)
testdir = os.getcwd()
srcdir = '../..'
src_path =  os.path.abspath(os.path.join(testdir, srcdir))
sys.path.insert(0, os.path.abspath(src_path))

from pycrunch_trace.client.api import trace


from mhlib.l2 import l2


def test_l2_var():
    l2.L2EG_VAR,'efgh'

def test_l2_slow():
    x = l2.L2Mh()
    rtn = x.run()
    import time
    time.sleep(3)

def test_l2_ext():
    x = l2.L2Mh()
    rtn = x.slow()
    rtn = x.slow()

@trace
def run():
    test_l2_var()
    test_l2_slow()
    test_l2_ext()

if __name__ == '__main__':
    print ( sys.executable)
    print ( sys.version)
    print ( "Load the session file to http: // app.pytrace.com /")
    run()



# unit_test_mh.py

import os
import sys

testdir = os.getcwd()
srcdir = '../..'
src_path =  os.path.abspath(os.path.join(testdir, srcdir))
sys.path.insert(0, os.path.abspath(src_path))


import sys
import unittest
import mh

class TestMh(unittest.TestCase):
    def test_var(self):
         self.assertEqual(mh.EG_VAR2, 'ABCD')

    def test_func(self):
        self.assertEqual(mh.testFunction(), 'OK')

    def test_class(self):
        x = mh.Mh()
        x.runMh()
        self.assertEqual(100, x.runMh() )

if __name__ == '__main__':
    print (sys.version)
    print (mh)
    unittest.main()



'''Documentation for l2.py...'''

import time

L2EG_VAR='efgh'


def L2Test():
    '''L2 test funtion'''
    return 'ok'


class L2Mh (object):
    """class L2Mh documentation"""

    def run(self):
        """No documentation"""
        return 10

    def slow(self):
        """No documentation"""
        t = 5
        time.sleep(t)
        return t




'''
example of an internal module
'''

import time
from mhlib.l2 import l2


EG_VAR='abcd'

def test():
    '''example intenal function'''
    return 'ok'

class MhEg (object):
    '''example intenal class'''
    def runMhEg(self):
        '''example member function of an intenal class'''
        return 10

    def slow(self):
        '''no documentation'''
        t = 3
        time.sleep(t)
        return


    def call_external_func(self):
        '''no documentation'''
        x = l2.L2Mh()
        y = x.slow()
        return y



if __name__ == '__main__':
    pass




# mh.py
'''eg code to start a project with.
'''

import logging
import mhlib.eg


logger = logging.getLogger(__name__)


EG_VAR='ABCD'

def testFunction():
    '''an example function that returns a string'''
    return 'OK'


class Mh (object):
    '''an example class '''

    def runMh(self):
        '''an example member function'''
        logger.info('OK fo far')
        return 100


if __name__ == '__main__':
    logger.setLevel(logging.INFO)
    logger.info('Start')
    logging.basicConfig(level=logging.INFO,
                        format='%(asctime)s {%(filename)s:%(lineno)d} %(levelname)s - %(message)s',
                        datefmt='%Y-%m-%d %H:%M:%S',
                        # filename='lib1.log',
                        )
    Mh().runMh()

    logger.info('Done')
